@@ -6,7 +6,7 @@
 #'   The device. If not `NULL`, is returned as is.
 #' @export
 auto_device = function(device = NULL) {
-  if (device == "auto") {
+  if (!is.null(device) && device == "auto") {
     device = if (cuda_is_available()) "cuda" else "cpu"
     lg$debug("Auto-detected device '%s'.", device)
   }
